@@ -14,7 +14,7 @@ use Inline (
         ),
         ($ENV{LIBUSB_INCDIR} ? ( INC => "-I\"$ENV{LIBUSB_INCDIR}\"" ) : () ),
         NAME => 'Device::USB',
-        VERSION => '0.32',
+        VERSION => '0.37',
    );
 
 Inline->init();
@@ -39,17 +39,19 @@ use constant CLASS_HUB =>     9;
 use constant CLASS_DATA =>   10;
 use constant CLASS_VENDOR_SPEC => 0xff;
 
+=encoding utf8
+
 =head1 NAME
 
-Device::USB - Use libusb to access USB devices.
+Device::USB - Use libusb to access USB devices. (DEPRECATED)
 
 =head1 VERSION
 
-Version 0.32
+Version 0.37
 
 =cut
 
-our $VERSION=0.32;
+our $VERSION=0.37;
 
 
 =head1 SYNOPSIS
@@ -77,6 +79,10 @@ the method name prepended with "usb_".
 
 =head1 DESCRIPTION
 
+This module is deprecated as of version 0.37. I have not had the time
+or need to update the module, and no one has been willing to take it
+over.
+
 This module provides a Perl interface to the C library libusb. This library
 supports a relatively full set of functionality to access a USB device. In
 addition to the libusb, functioality, Device::USB provides a few
@@ -448,6 +454,116 @@ sub get_busses
 
 =back
 
+=head1 LIBRARY INTERFACE
+
+The raw api of the libusb library is also :
+
+=over 4
+
+=item DeviceUSBDebugLevel()
+
+
+=item libusb_init()
+
+
+=item libusb_find_busses()
+
+
+=item libusb_find_devices()
+
+
+=item libusb_get_busses()
+
+
+=item libusb_open(void *dev)
+
+
+=item libusb_close(void *dev)
+
+
+=item libusb_set_configuration(void *dev, int configuration)
+
+
+=item libusb_set_altinterface(void *dev, int alternate)
+
+
+=item libusb_clear_halt(void *dev, unsigned int ep)
+
+
+=item libusb_reset(void *dev)
+
+
+=item libusb_get_driver_np(void *dev, int interface, char *name, unsigned int namelen)
+
+
+=item libusb_detach_kernel_driver_np(void *dev, int interface)
+
+
+=item libusb_claim_interface(void *dev, int interface)
+
+
+=item libusb_release_interface(void *dev, int interface)
+
+
+=item libusb_control_msg(void *dev, int requesttype, int request, int value, int index, char *bytes, int size, int timeout)
+
+
+=item libusb_get_string(void *dev, int index, int langid, char *buf, size_t buflen)
+
+
+=item libusb_get_string_simple(void *dev, int index, char *buf, size_t buflen)
+
+
+=item libusb_get_descriptor(void *dev, unsigned char type, unsigned char index, char *buf, int size)
+
+
+=item libusb_get_descriptor_by_endpoint(void *dev, int ep, unsigned char type, unsigned char index, char *buf, int size)
+
+
+=item libusb_bulk_write(void *dev, int ep, char *bytes, int size, int timeout)
+
+
+=item libusb_bulk_read(void *dev, int ep, char *bytes, int size, int timeout)
+
+
+=item libusb_interrupt_write(void *dev, int ep, char *bytes, int size, int timeout)
+
+
+=item libusb_interrupt_read(void *dev, int ep, char *bytes, int size, int timeout)
+
+
+=item lib_get_usb_busses()
+
+Return the complete list of information after finding busses and devices.
+
+Before calling this function, remember to call find_busses and find_devices.
+
+returns a reference to an array of busses.
+
+=item lib_list_busses()
+
+Return the complete list of information after finding busses and devices.
+
+By using this function, you do not need to do the find_* calls yourself.
+
+returns a reference to an array of busses.
+
+=item lib_find_usb_device( int vendor, int product )
+
+Find a particular device
+
+   vendor  - the vendor id
+   product - product id for that vendor
+
+returns a pointer to the device if it is found, NULL otherwise.
+
+=item lib_debug_mode( int unsafe_level )
+
+Set debugging level: 0: off, 1: some messages, 2: verbose
+Values outside range are forced into range.
+
+=back
+
 =head1 DIAGNOSTICS
 
 This is an explanation of the diagnostic and error messages this module
@@ -461,7 +577,7 @@ that is the entire reason for the module's existence.
 
 =head1 AUTHOR
 
-G. Wade Johnson (wade at anomaly dot org)
+G. Wade Johnson (gwadej at cpan dot org)
 Paul Archer (paul at paularcher dot org)
 
 Houston Perl Mongers Group
@@ -478,7 +594,7 @@ your bug as I make changes.
 
 =head1 FOR MORE INFORMATION
 
-The project is hosted at Google Code L<http://code.google.com/p/perl-device-usb/>.
+The project is hosted at github L<https://github.com/gwadej/perl-device-usb/>.
 More information on the project, including installation help is avaliable on the
 Wiki.
 
@@ -505,7 +621,8 @@ Thanks to Mike McCauley for support of C<usb_get_driver_np> and
 C<usb_detach_kernel_driver_np>.
 
 Thanks to Vadim Mikhailov for fixing a compile problem with VC6 on Windows
-and then chipping in again for VS 2005 on Windows.
+and then chipping in again for VS 2005 on Windows, and yet again to fix
+warnings on C99-compliant compilers.
 
 Thanks to John R. Hogheruis for information about modifying the Inline
 parameters for compiling with Strawberry Perl on Windows.
@@ -515,7 +632,7 @@ interrupt_read.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2009 Houston Perl Mongers
+Copyright 2006-2013 Houston Perl Mongers
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -557,17 +674,17 @@ void *libusb_get_busses()
     return usb_get_busses();
 }
 
-void *libusb_open(char *dev)
+void *libusb_open(void *dev)
 {
     return usb_open( (struct usb_device*)dev );
 }
 
-int libusb_close(char *dev)
+int libusb_close(void *dev)
 {
     return usb_close((usb_dev_handle *)dev);
 }
 
-int libusb_set_configuration(char *dev, int configuration)
+int libusb_set_configuration(void *dev, int configuration)
 {
     if(DeviceUSBDebugLevel())
     {
@@ -576,7 +693,7 @@ int libusb_set_configuration(char *dev, int configuration)
     return usb_set_configuration((usb_dev_handle *)dev, configuration);
 }
 
-int libusb_set_altinterface(char *dev, int alternate)
+int libusb_set_altinterface(void *dev, int alternate)
 {
     if(DeviceUSBDebugLevel())
     {
@@ -585,7 +702,7 @@ int libusb_set_altinterface(char *dev, int alternate)
     return usb_set_altinterface((usb_dev_handle *)dev, alternate);
 }
 
-int libusb_clear_halt(char *dev, unsigned int ep)
+int libusb_clear_halt(void *dev, unsigned int ep)
 {
     if(DeviceUSBDebugLevel())
     {
@@ -594,12 +711,12 @@ int libusb_clear_halt(char *dev, unsigned int ep)
     return usb_clear_halt((usb_dev_handle *)dev, ep);
 }
 
-int libusb_reset(char *dev)
+int libusb_reset(void *dev)
 {
     return usb_reset((usb_dev_handle *)dev);
 }
 
-int libusb_get_driver_np(char *dev, int interface, char *name, unsigned int namelen)
+int libusb_get_driver_np(void *dev, int interface, char *name, unsigned int namelen)
 {
     int ret = 0;
     if(DeviceUSBDebugLevel())
@@ -615,7 +732,7 @@ int libusb_get_driver_np(char *dev, int interface, char *name, unsigned int name
 #endif
 }
 
-int libusb_detach_kernel_driver_np(char *dev, int interface)
+int libusb_detach_kernel_driver_np(void *dev, int interface)
 {
     if(DeviceUSBDebugLevel())
     {
@@ -628,7 +745,7 @@ int libusb_detach_kernel_driver_np(char *dev, int interface)
 #endif
 }
 
-int libusb_claim_interface(char *dev, int interface)
+int libusb_claim_interface(void *dev, int interface)
 {
     if(DeviceUSBDebugLevel())
     {
@@ -637,7 +754,7 @@ int libusb_claim_interface(char *dev, int interface)
     return usb_claim_interface((usb_dev_handle *)dev, interface);
 }
 
-int libusb_release_interface(char *dev, int interface)
+int libusb_release_interface(void *dev, int interface)
 {
     if(DeviceUSBDebugLevel())
     {
@@ -646,7 +763,7 @@ int libusb_release_interface(char *dev, int interface)
     return usb_release_interface((usb_dev_handle *)dev, interface);
 }
 
-void libusb_control_msg(char *dev, int requesttype, int request, int value, int index, char *bytes, int size, int timeout)
+void libusb_control_msg(void *dev, int requesttype, int request, int value, int index, char *bytes, int size, int timeout)
 {
     int i = 0;
     int retval = 0;
@@ -688,54 +805,54 @@ void libusb_control_msg(char *dev, int requesttype, int request, int value, int
     Inline_Stack_Done;
 }
 
-int libusb_get_string(char *dev, int index, int langid, char *buf, size_t buflen)
+int libusb_get_string(void *dev, int index, int langid, char *buf, size_t buflen)
 {
     if(DeviceUSBDebugLevel())
     {
-        printf( "libusb_get_string( %d, %d, %p, %u )\n",
-            index, langid, buf, buflen
+        printf( "libusb_get_string( %d, %d, %p, %lu )\n",
+            index, langid, buf, (unsigned long)buflen
         );
     }
     return usb_get_string((usb_dev_handle *)dev, index, langid, buf, buflen);
 }
 
-int libusb_get_string_simple(char *dev, int index, char *buf, size_t buflen)
+int libusb_get_string_simple(void *dev, int index, char *buf, size_t buflen)
 {
     if(DeviceUSBDebugLevel())
     {
-        printf( "libusb_get_string_simple( %d, %p, %u )\n",
-            index, buf, buflen
+        printf( "libusb_get_string_simple( %d, %p, %lu )\n",
+            index, buf, (unsigned long)buflen
         );
     }
     return usb_get_string_simple((usb_dev_handle *)dev, index, buf, buflen);
 }
 
-int libusb_get_descriptor(char *dev, unsigned char type, unsigned char index, void *buf, int size)
+int libusb_get_descriptor(void *dev, unsigned char type, unsigned char index, char *buf, int size)
 {
     return usb_get_descriptor((usb_dev_handle *)dev, type, index, buf, size);
 }
 
-int libusb_get_descriptor_by_endpoint(char *dev, int ep, unsigned char type, unsigned char index, void *buf, int size)
+int libusb_get_descriptor_by_endpoint(void *dev, int ep, unsigned char type, unsigned char index, char *buf, int size)
 {
     return usb_get_descriptor_by_endpoint((usb_dev_handle *)dev, ep, type, index, buf, size);
 }
 
-int libusb_bulk_write(char *dev, int ep, char *bytes, int size, int timeout)
+int libusb_bulk_write(void *dev, int ep, char *bytes, int size, int timeout)
 {
     return usb_bulk_write((usb_dev_handle *)dev, ep, bytes, size, timeout);
 }
 
-int libusb_bulk_read(char *dev, int ep, char *bytes, int size, int timeout)
+int libusb_bulk_read(void *dev, int ep, char *bytes, int size, int timeout)
 {
     return usb_bulk_read((usb_dev_handle *)dev, ep, bytes, size, timeout);
 }
 
-int libusb_interrupt_write(char *dev, int ep, char *bytes, int size, int timeout)
+int libusb_interrupt_write(void *dev, int ep, char *bytes, int size, int timeout)
 {
     return usb_interrupt_write((usb_dev_handle *)dev, ep, bytes, size, timeout);
 }
 
-int libusb_interrupt_read(char *dev, int ep, char *bytes, int size, int timeout)
+int libusb_interrupt_read(void *dev, int ep, char *bytes, int size, int timeout)
 {
     return usb_interrupt_read((usb_dev_handle *)dev, ep, bytes, size, timeout);
 }
@@ -760,7 +877,7 @@ static void hashStoreBcd( HV *hash, const char *key, long value )
 
     sprintf( buffer, "%d.%d%d", major, minor, subminor );
 
-    hv_store( hash, key, strlen( key ), newSVpv( buffer, strlen( buffer ) ), 0 );
+    (void) hv_store( hash, key, strlen( key ), newSVpv( buffer, strlen( buffer ) ), 0 );
 }
 
 /*
@@ -768,7 +885,7 @@ static void hashStoreBcd( HV *hash, const char *key, long value )
  */
 static void hashStoreInt( HV *hash, const char *key, long value )
 {
-    hv_store( hash, key, strlen( key ), newSViv( value ), 0 );
+    (void) hv_store( hash, key, strlen( key ), newSViv( value ), 0 );
 }
 
 /*
@@ -776,7 +893,7 @@ static void hashStoreInt( HV *hash, const char *key, long value )
  */
 static void hashStoreString( HV *hash, const char *key, const char *value )
 {
-    hv_store( hash, key, strlen( key ), newSVpv( value, strlen( value ) ), 0 );
+    (void) hv_store( hash, key, strlen( key ), newSVpv( value, strlen( value ) ), 0 );
 }
 
 /*
@@ -784,7 +901,7 @@ static void hashStoreString( HV *hash, const char *key, const char *value )
  */
 static void hashStoreSV( HV *hash, const char *key, SV *value )
 {
-    hv_store( hash, key, strlen( key ), value, 0 );
+    (void) hv_store( hash, key, strlen( key ), value, 0 );
 }
 
 /*
